#!/bin/bash

set -e

copy_filehooks_code_to_gitlab() {
    # filehooks to install in GitLab
    echo "Installing file-hook script(s) in GitLab"
    if [ -z "$GITLAB_HOME" ]; then
        echo "Error: \$GITLAB_HOME is not set."
        exit 1
    fi
    if [ -z "$INDEXING_SERVICE_URL" ]; then
        echo "Error: \$INDEXING_SERVICE_URL is not set. It is needed inside sharing_gitlab container"
        exit 1
    fi
    if [ -d "$GITLAB_HOME/file_hooks/" ]; then
        sudo rm -rf "$GITLAB_HOME/file_hooks/"*
    else
        sudo mkdir "$GITLAB_HOME/file_hooks"
    fi
    sudo cp scripts/* "$GITLAB_HOME/file_hooks/"
    sudo chmod -R 755 "$GITLAB_HOME/file_hooks/"

    sudo mkdir "$GITLAB_HOME/file_hooks/utils"
    sudo cp requirements.txt setup.py "$GITLAB_HOME/file_hooks/utils"
    echo "Utility code successfully installed in GitLab"
}

GITLAB_CONTAINER=sharing_gitlab
while test $# -gt 0; do
    case "$1" in
    *)
        echo "unknown option $1"
        show_help
        exit 1
        ;;
    esac
done

echo "Checking GitLab health status..."
if [ "$(docker inspect -f "{{.State.Health.Status}}" "$GITLAB_CONTAINER")" != "healthy" ]; then
    echo "$GITLAB_CONTAINER is not healthy. Aborting!"
    exit 1
fi
echo "GitLab is healthy!"

copy_filehooks_code_to_gitlab

docker exec "$GITLAB_CONTAINER" /bin/sh -c "cd /opt/gitlab/embedded/service/gitlab-rails/file_hooks && pip3 install -r utils/requirements.txt"

