import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { UserManagementService } from 'app/admin/user-management/service/user-management.service';
import { User } from 'app/admin/user-management/user-management.model';
import { Account } from 'app/core/auth/account.model';
import { AccountService } from 'app/core/auth/account.service';
import { SearchService } from 'app/search/service/search-service';
import { SearchResultDTO } from 'app/shared/model/search/search-result-dto.model';
import { ReviewManagementService } from '../review-management.service';
import { Review } from '../review.model';

@Component({
  selector: 'jhi-review-management-update',
  templateUrl: './review-management-update.component.html',
})
export class ReviewManagementUpdateComponent implements OnInit {
  currentAccount: Account | null = null;
  users: User[] | undefined;
  results: SearchResultDTO[] = [];
  selectedExercise: SearchResultDTO | undefined;
  reviews: Review[] = [];
  search = '';
  reviewToEdit: Review | undefined;
  checkedListExercise: string[] = [];
  checkedListUser: string[] = [];

  constructor(
    private userService: UserManagementService,
    private accountService: AccountService,
    private searchService: SearchService,
    private reviewManagementService: ReviewManagementService,
    private route: ActivatedRoute
  ) {}

  ngOnInit(): void {
    this.accountService.identity().subscribe(account => (this.currentAccount = account));
    this.loadAll();
    this.route.paramMap.subscribe(params => {
      const id = params.get('id');
      console.log(id);
      if (id) {
        this.reviewManagementService.find(+id).subscribe(review => {
          this.reviewToEdit = review;
          this.checkedListExercise.push(review.resource!);
          this.checkedListUser = review.users!;
        });
      }
    });
    this.reviewManagementService.getAllWithStatistics().subscribe(reviews => {
      this.reviews = reviews;
    });
  }

  loadAll(): void {
    this.userService.loadAll().subscribe(users => {
      this.users = users;
    });
    this.searchService.getAllResources().subscribe({
      next: (data: SearchResultDTO[]) => {
        this.results = this.results
          .concat(data)
          .filter((value, index, self) => self.findIndex(t => t.metadata.title === value.metadata.title) === index);
      },
      error: () => (this.results = []),
    });
  }

  shareCheckedUserList(users: string[]) {
    this.reviewToEdit!.users = users;
  }
  shareExercise(exercise: SearchResultDTO) {
    this.selectedExercise = exercise;
    this.reviewToEdit!.resource = exercise.metadata.title;
  }
  submitReview() {
    this.selectedExercise = this.results.find(exercise => exercise.metadata.title === this.reviewToEdit!.resource);
    const res = this.reviewToEdit!.users!.filter(o => this.selectedExercise?.metadata.contributor?.some(x => x.email == o));

    if (res.length > 0) {
      alert('The selected users: ' + res.toString() + ' ,are already contributors of this exercise. Please select other users.');
      return;
    }

    const res2 = this.reviewToEdit!.users!.filter(o => this.selectedExercise?.metadata.creator.some(x => x.email == o));

    if (res2.length > 0) {
      alert('The selected users: ' + res2.toString() + ' ,are already creators of this exercise. Please select other users.');
      return;
    }

    const res3 = this.reviewToEdit!.users!.filter(o => this.selectedExercise?.metadata.publisher.some(x => x.email == o));

    if (res3.length > 0) {
      alert('The selected users: ' + res3.toString() + ' ,are already publisher of this exercise. Please select other users.');
      return;
    }

    if (
      this.reviews.filter(e => e.resource == this.selectedExercise?.metadata.title).length > 0 &&
      this.reviewToEdit?.resource != this.selectedExercise?.metadata.title
    ) {
      alert(
        'The selected exercise: ' + this.selectedExercise!.metadata.title + ' ,is already in the database. Please select other exercise.'
      );
      return;
    }

    this.reviewManagementService.update(this.reviewToEdit!).subscribe();
  }
}
