import { HttpClientModule } from '@angular/common/http';
import { HttpClientTestingModule, HttpTestingController } from '@angular/common/http/testing';
import { TestBed } from '@angular/core/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { TranslateModule } from '@ngx-translate/core';
import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { LocalStorageService, SessionStorageService } from 'ngx-webstorage';
import { ExerciseService } from './exercise.service';

describe('ExerciseService', () => {
  let service: ExerciseService;
  let httpMock: HttpTestingController;
  let applicationConfigService: ApplicationConfigService;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [HttpClientTestingModule, HttpClientModule, TranslateModule.forRoot(), RouterTestingModule],
      declarations: [],
      providers: [ApplicationConfigService, LocalStorageService, SessionStorageService],
    });

    applicationConfigService = TestBed.inject(ApplicationConfigService);
    service = TestBed.inject(ExerciseService);
    httpMock = TestBed.inject(HttpTestingController);
  });

  it('should inject', () => {
    expect(service).toBeTruthy();
  });

  it('test Caching', () => {
    httpMock.expectNone({
      method: 'GET',
      url: applicationConfigService.getEndpointFor('api/exercise/443'),
    });
    let result443 = null;
    let result444 = null;

    service.loadExercise('443').subscribe((result: any) => {
      result443 = result;
    });
    const testRequest443 = httpMock.expectOne({
      method: 'GET',
      url: applicationConfigService.getEndpointFor('api/exercise/443'),
    });

    service.loadExercise('444').subscribe(result => {
      result444 = result;
    });
    expect(result443).toBeUndefined(); // still waiting for response
    expect(result444).toBeUndefined(); // still waiting for response
    const testRequest444 = httpMock.expectOne({
      method: 'GET',
      url: applicationConfigService.getEndpointFor('api/exercise/444'),
    });

    testRequest443.flush({
      kaese: 'kaese443',
    });
    testRequest444.flush({
      kaese: 'kaese444',
    });
    expect(result443).toEqual({ kaese: 'kaese443' });
    expect(result444).toEqual({ kaese: 'kaese444' });

    service.loadExercise('444').subscribe(result => {
      result444 = result;
    });
    expect(result443).toEqual({ kaese: 'kaese443' });
    expect(result444).toEqual({ kaese: 'kaese444' });
    httpMock.expectNone({});
  });
});
