import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';

import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { map, Observable } from 'rxjs';
import { NgHttpCachingHeaders } from 'ng-http-caching';

export interface BroadCastMessage {
  message: string;
  starts_at: Date;
  ends_at: Date;

  color: string;
  font: string;
  id: number;
  active: boolean; // false,
  target_path: string; // "*/welcome",
  broadcast_type: string; // "banner",
  dismissable: boolean; // false
  target_access_levels: number[];
}

/**
 provides infrastructure services for Plugins
 */
@Injectable({ providedIn: 'root' })
export class MessageService {
  public messageResourceURL = this.applicationConfigService.getEndpointFor('api/applicationInfo/broadcastMessages');

  private messages = new Array<BroadCastMessage>();

  constructor(protected http: HttpClient, private applicationConfigService: ApplicationConfigService) {}

  public getActiveMessages(): Observable<BroadCastMessage[]> {
    const now = new Date();
    return this.getMessages().pipe(map(messages => messages.filter(m => m.starts_at <= now && m.ends_at >= now)));
  }

  public getMessages(): Observable<BroadCastMessage[]> {
    return this.http
      .get<Array<BroadCastMessage>>(this.messageResourceURL, {
        headers: {
          [NgHttpCachingHeaders.ALLOW_CACHE]: '1',
        },
      })
      .pipe(
        map(messages => {
          messages.forEach(m => {
            m.starts_at = new Date(m.starts_at);
            m.ends_at = new Date(m.ends_at);
          });
          return messages;
        })
      );
  }
}
